<style>
    .nav {
        background-color: #4B6788;
        height: 40px;
        color: #ffffff;
        line-height: 40px;
        padding: 0 10px;
    }

    .nav a {
        color: #ffffff;
    }
</style>
<div class="nav">
    <a href="{% url 'bee_django_coin:coin_type_list' %}">类型管理</a> |
    <a href="{% url 'bee_django_coin:coin_record_add' user_id=request.user.id %}">发M币</a> |
    <a href="{% url 'bee_django_coin:user_record_list' user_id=request.user.id %}">发放记录</a> |
    <a href="{% url 'bee_django_coin:user_rank_list' %}">M币排行</a> |

</div>
{% if messages %}
    {% load bootstrap3 %}
    {% bootstrap_messages messages %}
{% endif %}